#ifndef _usersmeter_h
#define _usersmeter_h


#include "users.h"


Users getUsers();


#endif // _usersmeter_h
